@@ -1,5 +1,9 @@
 #!/bin/bash -e
 
+if [[ "$OSTYPE" == "darwin"* ]]; then
+    exit 0
+fi
+
 AUTOCONF=http://ftp.gnu.org/gnu/autoconf/autoconf-2.69.tar.gz
 AUTOMAKE=http://ftp.gnu.org/gnu/automake/automake-1.14.1.tar.gz
 LIBTOOL=http://alpha.gnu.org/gnu/libtool/libtool-2.4.2.418.tar.gz
